document.addEventListener('DOMContentLoaded', function() {
  // Initialize variables
  let currentExperiment = 'dynamic';
  let chart = null;
  
  // Update parameter value displays
  document.querySelectorAll('input[type="range"]').forEach(input => {
    const valueDisplay = input.nextElementSibling;
    input.addEventListener('input', () => {
      valueDisplay.textContent = input.value;
    });
  });

  // Switch between experiments
  document.querySelectorAll('.experiment-btn').forEach(btn => {
    btn.addEventListener('click', () => {
      document.querySelectorAll('.experiment-btn').forEach(b => b.classList.remove('active'));
      btn.classList.add('active');
      currentExperiment = btn.dataset.experiment;
      resetResults();
    });
  });

  // Run experiment
  document.getElementById('runExperiment').addEventListener('click', async () => {
    const btn = document.getElementById('runExperiment');
    btn.disabled = true;
    btn.textContent = 'Running...';

    try {
      await runExperiment();
    } catch (error) {
      console.error('Error running experiment:', error);
    } finally {
      btn.disabled = false;
      btn.textContent = 'Run Experiment';
    }
  });

  function resetResults() {
    document.getElementById('aucScore').textContent = '-';
    document.getElementById('ksScore').textContent = '-';
    document.getElementById('logLoss').textContent = '-';
    if (chart) {
      chart.destroy();
    }
  }

  async function runExperiment() {
    // Simulate training process
    const epochs = parseInt(document.getElementById('epochs').value);
    const lossData = [];
    
    for (let i = 0; i < epochs; i++) {
      const loss = 1 / (1 + Math.exp(i/10)) + Math.random() * 0.1;
      lossData.push(loss);
      await new Promise(resolve => setTimeout(resolve, 50));
      updateChart(lossData);
    }

    // Update metrics with simulated results
    const metrics = generateMetrics();
    updateMetrics(metrics);
  }

  function generateMetrics() {
    return {
      auc: (0.85 + Math.random() * 0.1).toFixed(4),
      ks: (0.75 + Math.random() * 0.1).toFixed(4),
      logLoss: (0.3 + Math.random() * 0.1).toFixed(4)
    };
  }

  function updateMetrics(metrics) {
    document.getElementById('aucScore').textContent = metrics.auc;
    document.getElementById('ksScore').textContent = metrics.ks;
    document.getElementById('logLoss').textContent = metrics.logLoss;
  }

  function updateChart(data) {
    const ctx = document.getElementById('lossChart').getContext('2d');
    
    if (chart) {
      chart.destroy();
    }

    chart = new Chart(ctx, {
      type: 'line',
      data: {
        labels: Array.from({length: data.length}, (_, i) => i + 1),
        datasets: [{
          label: 'Training Loss',
          data: data,
          borderColor: '#3498db',
          tension: 0.4,
          fill: false
        }]
      },
      options: {
        responsive: true,
        maintainAspectRatio: false,
        scales: {
          y: {
            beginAtZero: true
          }
        }
      }
    });
  }

  // Simple Chart implementation
  class Chart {
    constructor(ctx, config) {
      this.ctx = ctx;
      this.config = config;
      this.draw();
    }

    draw() {
      const { ctx, config } = this;
      const { data, options } = config;
      const dataset = data.datasets[0];
      
      ctx.clearRect(0, 0, ctx.canvas.width, ctx.canvas.height);
      
      // Draw line
      ctx.beginPath();
      ctx.strokeStyle = dataset.borderColor;
      ctx.lineWidth = 2;
      
      const xStep = ctx.canvas.width / (dataset.data.length - 1);
      const yScale = ctx.canvas.height / Math.max(...dataset.data);
      
      dataset.data.forEach((point, i) => {
        const x = i * xStep;
        const y = ctx.canvas.height - (point * yScale);
        
        if (i === 0) {
          ctx.moveTo(x, y);
        } else {
          ctx.lineTo(x, y);
        }
      });
      
      ctx.stroke();
    }

    destroy() {
      this.ctx.clearRect(0, 0, this.ctx.canvas.width, this.ctx.canvas.height);
    }
  }
});
